Wrappers, Templates, And Miscellaneous Formats
==============================================

Handlers for archive wrappers, templates, log files, and placeholder formats.

.. autosummary::
   :toctree: generated

   etlplus.file.gz
   etlplus.file.hbs
   etlplus.file.jinja2
   etlplus.file.log
   etlplus.file.mustache
   etlplus.file.stub
   etlplus.file.vm
   etlplus.file.zip
